==> 0.1.3.tar.gz: ios/Classes/AttestrFlowxDelegate.swift <==
import Flutter
import UIKit
import attestr_flowx

public class AttestrFlowxDelegate: UIViewController, AttestrFlowxEventProtocol {
    
    private var pendingResult: FlutterResult!

    static let FLOW_COMPLETE = 0
    static let FLOW_SKIP = 1
    static let FLOW_ERROR = 2
    
    public func launchFlow(options : Dictionary<String, Any>, result: @escaping FlutterResult){
        
        self.pendingResult = result
        
        let hs = options["hs"] as? String
        let cl = options["cl"] as? String
        let lc = options["lc"] as? String
        let retry = options["retry"] as? Bool
        let qr = options["qr"] as? [String : String]
        
        let flow = AttestrFlowx().initialize(cl: cl!, hs: hs!, self)
        flow?.launch(lc: lc!, retry: retry!, qr: qr!)
    }
    
    public func onFlowxSuccess(_ data: [String : AnyObject]) {

        var newData = [String : AnyObject]()
        newData["type"] =  AttestrFlowxDelegate.FLOW_COMPLETE as AnyObject

        var result = [String : AnyObject]()
        result["message"] = data["message"] as AnyObject

        newData["data"] = result
        pendingResult(newData as NSDictionary)
    }
    
    public func onFlowxSkip(_ data: [String : AnyObject]) {
        var newData = [String : AnyObject]()
        newData["type"] = AttestrFlowxDelegate.FLOW_SKIP as AnyObject

        var result = [String : AnyObject]()
        result["message"] = data["message"] as AnyObject

        newData["data"] = result

        pendingResult(data as NSDictionary)
    }
    
    public func onFlowxError(_ data: [String : AnyObject]) {

        var newData = [String : AnyObject]()
        newData["type"] = AttestrFlowxDelegate.FLOW_ERROR as AnyObject

        var result = [String : AnyObject]()
        result["message"] = data["message"] as AnyObject

        newData["data"] = result
        pendingResult(data as NSDictionary)
    }
    
}

==> 0.2.7.tar.gz: ios/Classes/AttestrFlowxDelegate.swift <==
import Flutter
import UIKit
import attestr_flowx

public class AttestrFlowxDelegate: UIViewController, AttestrFlowxEventProtocol {
    
    private var pendingResult: FlutterResult!

    static let FLOW_COMPLETE = 0
    static let FLOW_SKIP = 1
    static let FLOW_ERROR = 2
    
    public func launchFlow(options : Dictionary<String, Any>, result: @escaping FlutterResult){
        
        self.pendingResult = result
        
        let hs = options["hs"] as? String
        let cl = options["cl"] as? String
        let lc = options["lc"] as? String
        let retry = options["retry"] as? Bool
        let qr = options["qr"] as? [String : String]
        
        let flow = AttestrFlowx().initialize(cl: cl!, hs: hs!, self)
        flow?.launch(lc: lc!, retry: retry!, qr: qr!)
    }
    
    public func onFlowxSuccess(_ data: [String : AnyObject]) {

        var newData = [String : AnyObject]()
        newData["type"] =  AttestrFlowxDelegate.FLOW_COMPLETE as AnyObject

        var result = [String : AnyObject]()
        result["message"] = data["message"] as AnyObject

        newData["data"] = result as AnyObject
        pendingResult(newData as NSDictionary)
    }
    
    public func onFlowxSkip(_ data: [String : AnyObject]) {
        var newData = [String : AnyObject]()
        newData["type"] = AttestrFlowxDelegate.FLOW_SKIP as AnyObject

        var result = [String : AnyObject]()
        result["message"] = data["message"] as AnyObject

        newData["data"] = result as AnyObject

        pendingResult(data as NSDictionary)
    }
    
    public func onFlowxError(_ data: [String : AnyObject]) {

        var newData = [String : AnyObject]()
        newData["type"] = AttestrFlowxDelegate.FLOW_ERROR as AnyObject

        var result = [String : AnyObject]()
        result["message"] = data["message"] as AnyObject

        newData["data"] = result as AnyObject
        pendingResult(data as NSDictionary)
    }
    
}
